PlausibleRouteNameExtractor typedef
PlausibleRouteNameExtractor =
String? Function(RouteSettings settings)
Resolves the page name that is reported for a route.
Return null to not report the route at all.
Implementation
typedef PlausibleRouteNameExtractor = String? Function(RouteSettings settings);